@@ -3,14 +3,14 @@ from igloo.models.permanent_token import PermanentToken
 from igloo.models.pending_environment_share import PendingEnvironmentShare
 from igloo.models.environment import Environment
 from igloo.models.thing import Thing
-from igloo.models.float_value import FloatValue
+from igloo.models.float_value import FloatVariable
 from igloo.models.pending_owner_change import PendingOwnerChange
 from igloo.models.notification import Notification
-from igloo.models.boolean_value import BooleanValue
-from igloo.models.string_value import StringValue
-from igloo.models.float_series_value import FloatSeriesValue
-from igloo.models.category_series_value import CategorySeriesValue
+from igloo.models.boolean_value import BooleanVariable
+from igloo.models.string_value import StringVariable
+from igloo.models.float_series_value import FloatSeriesVariable
+from igloo.models.category_series_value import CategorySeriesVariable
 from igloo.models.category_series_node import CategorySeriesNode
-from igloo.models.file_value import FileValue
+from igloo.models.file_value import FileVariable
 from igloo.models.float_series_node import FloatSeriesNode
 from igloo.main import NULL, null, GraphQLException, Client
